@@ -408,10 +408,15 @@ class Stack(object):
             self.server.send(tx, ta)
         except socket.error as ex:
             err = raeting.get_exception_error(ex)
-            if (err in [errno.EAGAIN, errno.EWOULDBLOCK,
-                             errno.ENETUNREACH, errno.ETIME,
-                             errno.EHOSTUNREACH, errno.EHOSTDOWN,
-                             errno.ECONNRESET]):
+            errors = [errno.EAGAIN,
+                      errno.EWOULDBLOCK,
+                      errno.ENETUNREACH,
+                      errno.EHOSTUNREACH,
+                      errno.EHOSTDOWN,
+                      errno.ECONNRESET]
+            if hasattr(errno, 'ETIME'):
+                errors.append[errno.ETIME]
+            if (err in errors):
                 # problem sending such as busy with last message. save it for later
                 laters.append((tx, ta))
                 blocks.append(ta)
